pub enum Jpeg2000CodecError {
UnsupportedDtype(AnyArrayDType),
HeaderEncodeFailed {
source: Jpeg2000HeaderError,
},
Jpeg2000EncodeFailed {
source: Jpeg2000CodingError,
},
SliceEncodeFailed {
source: Jpeg2000SliceError,
},
EncodedDataNotBytes {
dtype: AnyArrayDType,
},
EncodedDataNotOneDimensional {
shape: Vec<usize>,
},
HeaderDecodeFailed {
source: Jpeg2000HeaderError,
},
SliceDecodeFailed {
source: Jpeg2000SliceError,
},
DecodeTooManySlices,
Jpeg2000DecodeFailed {
source: Jpeg2000CodingError,
},
DecodeInvalidShape {
source: ShapeError,
},
MismatchedDecodeIntoArray {
source: AnyArrayAssignError,
},
}Expand description
Errors that may occur when applying the Jpeg2000Codec.
Variants
UnsupportedDtype(AnyArrayDType)
Jpeg2000Codec does not support the dtype
HeaderEncodeFailed
Jpeg2000Codec failed to encode the header
Fields
source: Jpeg2000HeaderErrorOpaque source error
Jpeg2000EncodeFailed
Jpeg2000Codec failed to encode the data
Fields
source: Jpeg2000CodingErrorOpaque source error
SliceEncodeFailed
Jpeg2000Codec failed to encode a slice
Fields
source: Jpeg2000SliceErrorOpaque source error
EncodedDataNotBytes
Jpeg2000Codec can only decode one-dimensional byte arrays but received
an array of a different dtype
Fields
dtype: AnyArrayDTypeThe unexpected dtype of the encoded array
EncodedDataNotOneDimensional
Jpeg2000Codec can only decode one-dimensional byte arrays but received
an array of a different shape
HeaderDecodeFailed
Jpeg2000Codec failed to decode the header
Fields
source: Jpeg2000HeaderErrorOpaque source error
SliceDecodeFailed
Jpeg2000Codec failed to decode a slice
Fields
source: Jpeg2000SliceErrorOpaque source error
DecodeTooManySlices
Jpeg2000Codec failed to decode from an excessive number of slices
Jpeg2000DecodeFailed
Jpeg2000Codec failed to decode the data
Fields
source: Jpeg2000CodingErrorOpaque source error
DecodeInvalidShape
Jpeg2000Codec decoded into an invalid shape not matching the data size
Fields
source: ShapeErrorThe source of the error
MismatchedDecodeIntoArray
Jpeg2000Codec cannot decode into the provided array
Fields
source: AnyArrayAssignErrorThe source of the error